#
# spec file for package python-isodate
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%{?sle15_python_module_pythons}
Name:           python-isodate
Version:        0.6.1
Release:        4.4
Summary:        An ISO 8601 Date/Time/Duration Parser and Formatter
License:        BSD-3-Clause
URL:            https://pypi.org/project/isodate/
Source:         https://files.pythonhosted.org/packages/source/i/isodate/isodate-%{version}.tar.gz
# https://github.com/gweis/isodate/commit/07d1602048083415bc22dc72cff152c9c2e0e021
Patch0:         python-isodate-no-six.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
This module implements ISO 8601 date, time and duration parsing.
The implementation follows ISO8601:2004 standard, and implements only
date/time representations mentioned in the standard. If something is not
mentioned there, then it is treated as non existent, and not as an allowed
option.

%prep
%setup -q -n isodate-%{version}
%autopatch -p1

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest discover -v src/

%files %{python_files}
%doc CHANGES.txt README.rst TODO.txt
%{python_sitelib}/*

%changelog
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Fri Oct 21 2022 pgajdos@suse.com
- added patches
  https://github.com/gweis/isodate/commit/07d1602048083415bc22dc72cff152c9c2e0e021
  + python-isodate-no-six.patch
* Mon Feb 14 2022 Dirk Müller <dmueller@suse.com>
- update to 0.6.1:
  * support python 3.10 ()
  * last version to support py 2.7
- drop coerce-decimal-to-int-python-310.patch (upstream)
* Mon Dec 13 2021 Steve Kowalik <steven.kowalik@suse.com>
- Add patch coerce-decimal-to-int-python-310.patch:
  * Support Python 3.10.
* Mon Nov  8 2021 Dirk Müller <dmueller@suse.com>
- add six dependency
* Wed May 26 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Sep 26 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Include in SLE-15 (bsc#1109694)
* Wed May  2 2018 adrian.glaubitz@suse.com
- update to version 0.6.0:
  - Support incomplete month date (Fabien Loffredo)
  - Rely on duck typing when doing duration maths
  - Support ':' as separator in fractional time zones (usrenmae)
* Wed May  3 2017 toddrme2178@gmail.com
- Implement single-spec version.
- Fix source URL.
* Mon Jan 30 2017 tbechtold@suse.com
- update to 0.5.4:
  - Fix parsing of Periods (Fabien Bochu)
  - Make Duration objects hashable (Geoffrey Fairchild)
  - Add multiplication to duration (Reinoud Elhorst)
- Use pypi.io as Source url
* Wed May  6 2015 benoit.monin@gmx.fr
- update to version 0.5.1:
  * fixed pickling of Duration objects
  * raise ISO8601Error when there is no 'T' separator in datetime
    strings
- additional changes from version 0.5.0:
  * ISO8601Error are subclasses of ValueError now
  * improve compatibility across various python variants and
    versions
  * raise exceptions when using fractional years and months in date
    maths with durations
  * renamed method todatetime on Duraction objects to totimedelta
- pass -q to test to avoid spamming the build log
- rename README.txt to README.rst: changed upstream
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Apr 17 2013 toddrme2178@gmail.com
- Re-add python-2to3.  It is needed for OpenSUSE <= 12.2
* Tue Apr 16 2013 p.drouand@gmail.com
- Remove BuildRequires: python-2to3, useless since included in main
  python devel package
- Add Requires: python3; fix build for OpenSUSE <= 12.2
* Sun Jan 13 2013 p.drouand@gmail.com
- Initial python3 support
* Fri Nov 23 2012 saschpe@suse.de
- Update to version 0.4.9:
  + support pickling FixedOffset instances
  + make sure parsed fractional seconds are in microseconds
  + add leading zeros when formattig microseconds (Jarom Loveridge)
- Spec file cleanup
* Fri May 18 2012 jfunk@funktronics.ca
- Initial release
